@@ -444,7 +444,7 @@ class Variable:
         # flatten into array C-style
         data = self._data_matrix.flatten("C")
 
-        if not self.dimensions:
+        if not self._domain.dimensions:
             index = None
         else:
             index = pd.MultiIndex.from_tuples(
@@ -869,7 +869,6 @@ class Variable:
             dim_name = dim.name
 
             for (_from_level, to_level, action, weight) in steps:
-                print("%s, %s, %s, %s" % (_from_level, to_level, action, weight))
                 if action == "expand":
                     result = result.expand(dim)
                 elif action == "squeeze":
